@@ -46,5 +46,7 @@ def list_archives(repository, storage_config, list_arguments, local_path='borg',
     )
 
     return execute_command(
-        full_command, output_log_level=None if list_arguments.json else logging.WARNING
+        full_command,
+        output_log_level=None if list_arguments.json else logging.WARNING,
+        error_on_warnings=False,
     )
